# Generated by Django 5.2.4 on 2025-08-06 00:57

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('wagtail_feathers', '0002_alter_featherbasepage_body'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='classifiergroup',
            options={'ordering': ['type', 'name'], 'verbose_name': 'Group of classifiers', 'verbose_name_plural': 'Groups of classifiers'},
        ),
    ]
