"""Utility functions and variables for the wagtail_feathers.models package."""

# List to store all FeatherPage models
FEATHER_PAGE_MODELS = []


def get_page_models():
    """Return a list of all FeatherPage models."""
    return FEATHER_PAGE_MODELS
