{% comment %}
    Content is coming from the StandardBlock StreamField
    class within `blocks.py`
{% endcomment %}

{% if self.size == 'h2' %}
    <h2>{{ self.heading_text }}</h2>

{% elif self.size == 'h3' %}
    <h3>{{ self.heading_text }}</h3>

{% elif self.size == 'h4' %}
    <h4>{{ self.heading_text }}</h4>

{% elif self.size == 'h5' %}
    <h5>{{ self.heading_text }}</h5>

{% elif self.size == 'h6' %}
    <h6>{{ self.heading_text }}</h6>

{% endif %}