# Generated by Django 5.2.4 on 2025-08-06 03:01

import django_extensions.db.fields
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('wagtail_feathers', '0007_remove_classifier_unique_classifier_group_name_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='classifiergroup',
            name='slug',
            field=django_extensions.db.fields.AutoSlugField(blank=True, editable=False, populate_from='name'),
        ),
    ]
