from django.apps import AppConfig


class WagtailFeathersConfig(AppConfig):
    default_auto_field = "django.db.models.BigAutoField"
    name = "wagtail_feathers"
    label = "wagtail_feathers"
    verbose_name = "Wagtail Feathers"
    
