# Generated by Django 5.2.4 on 2025-08-06 02:21

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('wagtail_feathers', '0006_make_translatable_fields_required'),
        ('wagtailcore', '0094_alter_page_locale'),
    ]

    operations = [
        migrations.RemoveConstraint(
            model_name='classifier',
            name='unique_classifier_group_name',
        ),
        migrations.RemoveConstraint(
            model_name='classifiergroup',
            name='unique_classifier_group_type_name',
        ),
        migrations.AddConstraint(
            model_name='classifier',
            constraint=models.UniqueConstraint(fields=('group', 'name', 'locale'), name='unique_classifier_group_name_locale'),
        ),
        migrations.AddConstraint(
            model_name='classifiergroup',
            constraint=models.UniqueConstraint(fields=('type', 'name', 'locale'), name='unique_classifier_group_type_name_locale'),
        ),
    ]
