# Generated by Django 5.2.4 on 2025-08-02 20:51

import wagtail.fields
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('wagtail_feathers', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='featherbasepage',
            name='body',
            field=wagtail.fields.StreamField([('heading_block', 3), ('paragraph_block', 4), ('markdown_block', 5), ('image_block', 9), ('image_grid', 12), ('image_collection_gallery', 14), ('block_quote', 18), ('embed_block', 19), ('cta_block', 34), ('card_block', 42), ('card_section', 49), ('faq_section', 56), ('table_block', 57)], blank=True, block_lookup={0: ('wagtail.blocks.CharBlock', (), {'required': True}), 1: ('wagtail.blocks.ChoiceBlock', [], {'blank': True, 'choices': [('', 'Select a header size'), ('h2', 'H2'), ('h3', 'H3'), ('h4', 'H4'), ('h5', 'H5'), ('h6', 'H6')], 'required': False}), 2: ('wagtail_feathers.blocks.ThemeVariantChooserBlock', (), {'component_type': 'heading', 'default': 'default', 'help_text': 'Select a theme variant for this component', 'label': 'Theme variant', 'required': False}), 3: ('wagtail.blocks.StructBlock', [[('heading_text', 0), ('size', 1), ('theme_variant', 2)]], {'label': 'Heading'}), 4: ('wagtail.blocks.RichTextBlock', (), {'description': 'A rich text paragraph', 'features': ['h2', 'h3', 'h4', 'bold', 'italic', 'link', 'ul', 'ol', 'superscript', 'subscript'], 'icon': 'pilcrow', 'label': 'Paragraph', 'preview_value': '\n            <h2>Our scientific commitment</h2>\n            <p>In the realm of science, <b>discovery</b> has <i>always</i> been our driving force.\n            <a href="https://en.wikipedia.org/wiki/Scientific_method">Scientific methods</a>\n            are crucial for progress, and – research is the most rewarding of all.\n            We take pride in transforming hypotheses and experiments into groundbreaking\n            findings with precision and rigor.</p>\n            ', 'template': 'wagtail_feathers/blocks/paragraph_block.html'}), 5: ('wagtailmarkdown.blocks.MarkdownBlock', (), {'icon': 'code', 'label': 'Markdown'}), 6: ('wagtail.images.blocks.ImageChooserBlock', (), {'required': True}), 7: ('wagtail.blocks.CharBlock', (), {'help_text': "If left blank, the image's global alt text will be used.", 'required': False}), 8: ('wagtail_feathers.blocks.ThemeVariantChooserBlock', (), {'component_type': 'image', 'default': 'default', 'help_text': 'Select a theme variant for this component', 'label': 'Theme variant', 'required': False}), 9: ('wagtail.blocks.StructBlock', [[('image', 6), ('image_alt_text', 7), ('theme_variant', 8)]], {'label': 'Image'}), 10: ('wagtail.blocks.StructBlock', [[('image', 6), ('image_alt_text', 7), ('theme_variant', 8)]], {}), 11: ('wagtail.blocks.ListBlock', (10,), {'help_text': 'Add images to display in the grid', 'label': 'Images'}), 12: ('wagtail.blocks.StructBlock', [[('images', 11)]], {'label': 'Image Grid'}), 13: ('wagtail_feathers.blocks.CollectionChooserBlock', (), {'label': 'Image Collection', 'required': True}), 14: ('wagtail.blocks.StructBlock', [[('collection', 13)]], {'label': 'Image Collection'}), 15: ('wagtail.blocks.RichTextBlock', (), {'required': True}), 16: ('wagtail.blocks.CharBlock', (), {'blank': True, 'label': 'e.g. Maxime Decooman', 'required': False}), 17: ('wagtail_feathers.blocks.ThemeVariantChooserBlock', (), {'component_type': 'quote', 'default': 'default', 'help_text': 'Select a theme variant for this component', 'label': 'Theme variant', 'required': False}), 18: ('wagtail.blocks.StructBlock', [[('quote', 15), ('attribution', 16), ('theme_variant', 17)]], {'label': 'Quote'}), 19: ('wagtail.embeds.blocks.EmbedBlock', (), {'description': 'An embedded video or other media', 'help_text': 'Insert an embed URL e.g https://www.youtube.com/watch?v=SGJFWirQ3ks', 'icon': 'media', 'label': 'Embed Block', 'preview_template': 'wagtail_feathers/preview/static_embed_block.html', 'preview_value': 'https://www.youtube.com/watch?v=mwrGSfiB1Mg', 'template': 'wagtail_feathers/blocks/embed_block.html'}), 20: ('wagtail.blocks.CharBlock', (), {'help_text': 'Call-to-action heading', 'max_length': 100}), 21: ('wagtail.blocks.RichTextBlock', (), {'features': ['bold', 'italic'], 'help_text': 'Supporting text for the call-to-action', 'required': False}), 22: ('wagtail.blocks.CharBlock', (), {'help_text': 'Text for the action button', 'max_length': 50}), 23: ('wagtail.blocks.PageChooserBlock', (), {'required': False}), 24: ('wagtail.documents.blocks.DocumentChooserBlock', (), {'required': False}), 25: ('wagtail.blocks.CharBlock', (), {'help_text': "Leave blank to use link's title.", 'required': False}), 26: ('wagtail.blocks.StructBlock', [[('page', 23), ('document', 24), ('title', 25)]], {}), 27: ('wagtail.blocks.URLBlock', (), {}), 28: ('wagtail.blocks.CharBlock', (), {'required': False}), 29: ('wagtail.blocks.BooleanBlock', (), {'help_text': 'Open the link in a new tab', 'required': False}), 30: ('wagtail.blocks.StructBlock', [[('link', 27), ('title', 28), ('link_target', 29)]], {}), 31: ('wagtail.blocks.StreamBlock', [[('internal', 26), ('external', 30)]], {'help_text': 'Link for the action button', 'max_num': 1}), 32: ('wagtail.blocks.ChoiceBlock', [], {'choices': [('default', 'Default'), ('primary', 'Primary'), ('secondary', 'Secondary'), ('accent', 'Accent')], 'help_text': 'Background color theme for the CTA section'}), 33: ('wagtail_feathers.blocks.ThemeVariantChooserBlock', (), {'component_type': 'cta', 'default': 'default', 'help_text': 'Select a theme variant for this component', 'label': 'Theme variant', 'required': False}), 34: ('wagtail.blocks.StructBlock', [[('heading', 20), ('text', 21), ('button_text', 22), ('button_link', 31), ('background_color', 32), ('theme_variant', 33)]], {'label': 'Call to Action'}), 35: ('wagtail.images.blocks.ImageChooserBlock', (), {'help_text': 'Card image', 'required': False}), 36: ('wagtail.blocks.CharBlock', (), {'help_text': 'Alt text for the card image', 'max_length': 100, 'required': False}), 37: ('wagtail.blocks.CharBlock', (), {'help_text': 'Card heading', 'max_length': 100}), 38: ('wagtail.blocks.RichTextBlock', (), {'features': ['bold', 'italic', 'link'], 'help_text': 'Card content text', 'required': False}), 39: ('wagtail.blocks.StreamBlock', [[('internal', 26), ('external', 30)]], {'help_text': 'Optional card link', 'max_num': 1, 'required': False}), 40: ('wagtail.blocks.CharBlock', (), {'help_text': "Text for the card link (e.g., 'Read More', 'Learn More')", 'max_length': 50, 'required': False}), 41: ('wagtail_feathers.blocks.ThemeVariantChooserBlock', (), {'component_type': 'card', 'default': 'default', 'help_text': 'Select a theme variant for this component', 'label': 'Theme variant', 'required': False}), 42: ('wagtail.blocks.StructBlock', [[('image', 35), ('image_alt', 36), ('heading', 37), ('text', 38), ('link', 39), ('link_text', 40), ('theme_variant', 41)]], {'label': 'Card'}), 43: ('wagtail.blocks.BooleanBlock', (), {'default': False, 'help_text': 'If checked, the section will span the full width of the page without container padding.', 'label': 'Full width', 'required': False}), 44: ('wagtail.blocks.CharBlock', (), {'form_classname': 'title', 'help_text': 'Section heading (will use H2 in templates)', 'icon': 'title', 'required': True}), 45: ('wagtail.blocks.BooleanBlock', (), {'help_text': 'If checked, the heading will be hidden from view and available to screen-readers only.', 'label': 'Screen reader only label', 'required': False}), 46: ('wagtail.blocks.StructBlock', [[('image', 35), ('image_alt', 36), ('heading', 37), ('text', 38), ('link', 39), ('link_text', 40), ('theme_variant', 41)]], {}), 47: ('wagtail.blocks.ListBlock', (46,), {'help_text': 'Add cards to display in this section (max 9 to avoid performances issues)', 'label': 'Cards', 'max_num': 9}), 48: ('wagtail_feathers.blocks.ThemeVariantChooserBlock', (), {'component_type': 'cards-section', 'default': 'default', 'help_text': 'Select a theme variant for this component', 'label': 'Theme variant', 'required': False}), 49: ('wagtail.blocks.StructBlock', [[('fluid', 43), ('heading', 44), ('sr_only_label', 45), ('cards', 47), ('theme_variant', 48)]], {'label': 'Card Section'}), 50: ('wagtail.blocks.CharBlock', (), {'help_text': 'Optional title for this FAQ section', 'max_length': 100, 'required': False}), 51: ('wagtail.blocks.ChoiceBlock', [], {'choices': [], 'help_text': 'Select FAQ category to display'}), 52: ('wagtail.blocks.IntegerBlock', (), {'default': 5, 'help_text': 'Maximum number of FAQ items to show', 'max_value': 20, 'min_value': 1}), 53: ('wagtail.blocks.BooleanBlock', (), {'default': True, 'help_text': "Show 'View All FAQs' link", 'required': False}), 54: ('wagtail.blocks.PageChooserBlock', (), {'help_text': "Link to full FAQ page (for 'View All' link)", 'required': False}), 55: ('wagtail_feathers.blocks.ThemeVariantChooserBlock', (), {'component_type': 'faq_embed', 'default': 'default', 'help_text': 'Select a theme variant for this component', 'label': 'Theme variant', 'required': False}), 56: ('wagtail.blocks.StructBlock', [[('section_title', 50), ('faq_category', 51), ('max_items', 52), ('show_view_all_link', 53), ('faq_page', 54), ('theme_variant', 55)]], {'label': 'FAQ Section'}), 57: ('wagtail.contrib.table_block.blocks.TableBlock', (), {'label': 'Table'})}),
        ),
    ]
