<div class="menu-divider" role="separator">
    {% if value.label %}
        <span class="menu-divider-label">{{ value.label }}</span>
    {% else %}
        <span class="menu-divider-line" aria-hidden="true"></span>
    {% endif %}
</div>